@@ -624,7 +624,7 @@ void QrSink::addVCard(QString user_data)
 
     QTemporaryFile file("/home/user/.mbarcode/temp/qt_tempXXXXXX.vcf");
     file.open();
-    file.write(user_data.toAscii());
+    file.write(user_data.toUtf8());
     file.close();
 
     file.setAutoRemove(false); // we'll do this at the end
